Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(41)

Unified Diff: third_party/WebKit/Source/platform/graphics/paint/PaintController.cpp

Issue 2523673004: [NOT FOR COMMIT] Fully replace SkCanvas uses.
Patch Set: Support Android build. Created 4 years ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: third_party/WebKit/Source/platform/graphics/paint/PaintController.cpp
diff --git a/third_party/WebKit/Source/platform/graphics/paint/PaintController.cpp b/third_party/WebKit/Source/platform/graphics/paint/PaintController.cpp
index 5fc5ffa781202a056345fe3f7e3bbb626ef8c05b..9820cd3527e13836268f8618da8082958fc1e726 100644
--- a/third_party/WebKit/Source/platform/graphics/paint/PaintController.cpp
+++ b/third_party/WebKit/Source/platform/graphics/paint/PaintController.cpp
@@ -572,7 +572,7 @@ size_t PaintController::approximateUnsharedMemoryUsage() const {
// TODO(jbroman): If display items begin to have significant external memory
// usage that's not shared with the embedder, we should account for it here.
//
// External objects, shared with the embedder, such as SkPicture, should be
// excluded to avoid double counting. It is the embedder's responsibility to
// count such objects.
//
@@ -589,7 +589,7 @@ size_t PaintController::approximateUnsharedMemoryUsage() const {
void PaintController::appendDebugDrawingAfterCommit(
const DisplayItemClient& displayItemClient,
- sk_sp<SkPicture> picture,
+ sk_sp<CdlPicture> picture,
const LayoutSize& offsetFromLayoutObject) {
DCHECK(m_newDisplayItemList.isEmpty());
DrawingDisplayItem& displayItem =
@@ -752,11 +752,11 @@ void PaintController::showUnderInvalidationError(
LOG(ERROR) << "See http://crbug.com/619103.";
#ifndef NDEBUG
- const SkPicture* newPicture =
+ const CdlPicture* newPicture =
newItem.isDrawing()
? static_cast<const DrawingDisplayItem&>(newItem).picture()
: nullptr;
- const SkPicture* oldPicture =
+ const CdlPicture* oldPicture =
oldItem && oldItem->isDrawing()
? static_cast<const DrawingDisplayItem*>(oldItem)->picture()
: nullptr;
@@ -862,7 +862,7 @@ String PaintController::displayItemListAsDebugString(
}
#ifndef NDEBUG
if (showPictures && displayItem.isDrawing()) {
- if (const SkPicture* picture =
+ if (const CdlPicture* picture =
static_cast<const DrawingDisplayItem&>(displayItem).picture()) {
stringBuilder.append(", picture: ");
stringBuilder.append(pictureAsDebugString(picture));
@@ -572,7 +572,7 @@ size_t PaintController::approximateUnsharedMemoryUsage() const {
// usage that's not shared with the embedder, we should account for it here.
//
- // External objects, shared with the embedder, such as SkPicture, should be
+ // External objects, shared with the embedder, such as CdlPicture, should be
// excluded to avoid double counting. It is the embedder's responsibility to
// count such objects.

Powered by Google App Engine
This is Rietveld 408576698